aboutsummaryrefslogtreecommitdiffstats
path: root/config
diff options
context:
space:
mode:
authorJaKooLit <jimmielovejay@gmail.com>2023-12-10 17:53:46 +0900
committerJaKooLit <jimmielovejay@gmail.com>2023-12-10 17:53:46 +0900
commit49b5f3c5260eaf1af88e7b91fe8420fa748c16b9 (patch)
tree2cf88e221e3d835b1d0cd5fa20a4fc906b22cf0b /config
parentce56138a3d50b42ee4ef857ed0e76dbefdde5b15 (diff)
additional
Diffstat (limited to 'config')
-rwxr-xr-xconfig/hypr/initial-boot.sh4
1 files changed, 3 insertions, 1 deletions
diff --git a/config/hypr/initial-boot.sh b/config/hypr/initial-boot.sh
index 7f58b9d6..b173e04f 100755
--- a/config/hypr/initial-boot.sh
+++ b/config/hypr/initial-boot.sh
@@ -29,9 +29,11 @@ if [ ! -f ~/.config/hypr/.initial_startup_done ]; then
"$scriptsDir/PywalSwww.sh" > /dev/null 2>&1 &
"$scriptsDir/Refresh.sh" > /dev/null 2>&1 &
# initiate GTK dark mode and apply icon theme
gsettings set org.gnome.desktop.interface gtk-theme Tokyonight-Dark-B > /dev/null 2>&1 &
gsettings set org.gnome.desktop.interface icon-theme TokyoNight-SE > /dev/null 2>&1 &
+ gsettings set org.gnome.desktop.interface cursor-theme Bibata-Modern-Ice > /dev/null 2>&1 &
+ gsettings set org.gnome.desktop.interface cursor-size 24 > /dev/null 2>&1 &
# initiate the kb_layout (for some reason) waybar cant launch it
"$scriptsDir/SwitchKeyboardLayout.sh" > /dev/null 2>&1 &
send patches to the email below
@@ -29,9 +29,11 @@ if [ ! -f ~/.config/hypr/.initial_startup_done ]; then
"$scriptsDir/PywalSwww.sh" > /dev/null 2>&1 &
"$scriptsDir/Refresh.sh" > /dev/null 2>&1 &
- # initiate GTK dark mode and apply icon theme
+ # initiate GTK dark mode and apply icon and cursor theme
gsettings set org.gnome.desktop.interface gtk-theme Tokyonight-Dark-B > /dev/null 2>&1 &
gsettings set org.gnome.desktop.interface icon-theme TokyoNight-SE > /dev/null 2>&1 &
yukais@pinapelz.com
include the subject [PATCH repo_name]
pinapelz.com
homepage